#include "config.h"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>
#include <EzGraph.h>
#include "file.h"
#include "getarg.h"
#include "layout.h"
#include "main.h"
#include "game.h"
#include "title.h"
#include "title_draw.h"
#include "select_stage.h"
#include "select_stage_draw.h"
#include "font.h"
#include "stage.h"
#include "draw.h"

void init(int argc, char *argv[]);
void quit(void);
main_state_t get_main_state(void);
void set_main_state(main_state_t state);

static main_state_t main_state;

unsigned char major_version = MAJOR_VERSION;
unsigned char minor_version = MINOR_VERSION;

// 右クリックで終了しないよう空のハンドラをつくっておく
void dummy_mouseh(int x, int y, unsigned int n){
}



int main(int argc, char *argv[]){

    init(argc, argv);

    //    set_main_state(ms_title);

    EzEventLoop();
    puts("quit");
    quit();
    return 0;
}

void init(int argc, char *argv[]){

    if (getarg(argc, argv) != 0){
        exit(1);
    }
    file_init(argv[0], get_opt_str("savedir"), SAVE_DIR, LOG_FILE);

    EzOpenWindow(WIN_WIDTH, WIN_HEIGHT);
    EzSetMouseHandler(dummy_mouseh);

    draw_init();
    font_init();
    game_init();
    title_draw_init();
    title_init();
    stage_init(argv[0]);
    select_stage_init();
    select_stage_draw_init();

    set_main_state(ms_title);
    //    set_main_state(ms_game);
}

void quit(void){
    printf("Bye.\n");
}

main_state_t get_main_state(void){
    return main_state;
}

void set_main_state(main_state_t state){
    //    printf("set main state %d\n", state);
    switch (state){
    case ms_title:
        setup_title();
        break;
    case ms_select_stage:
        setup_select_stage();
        break;
    case ms_game:
        setup_game();
        break;
    case ms_quit:
        EzExitEventLoop();
        break;
    default:
        log_error("Unknown main state %d\n", state);
        exit(1);
    }
}


#ifdef DUMMY
#include "title.h"
#include "howtoplay.h"
#include "stage_info.h"
#include "record.h"
#include "objective.h"
#include "draw.h"
#include "obj.h"
#include "stage.h"
#include "emap.h"
#include "anime.h"
#include "uty.h"





    //    srnd((unsigned int)time(NULL));
    EzSetFontSize(16);
    draw_init();
    record_init();
    objective_init();
    obj_init();
    emap_init();
    stage_init(argv[0]);
    game_init();
    select_stage_init();
    stage_info_init();
    anime_init();
}



#endif
